@@ -19,7 +19,7 @@
 #define OTRPLUGIN_H
 
 
-#include "kdebug.h"
+#include <kdebug.h>
 
 #include <kopeteplugin.h>
 #include <kopetemessagehandler.h>
@@ -65,16 +65,15 @@ public:
 	}
 };
 
-class OTRPlugin : public Kopete::Plugin
+class KDE_EXPORT OTRPlugin : public Kopete::Plugin
 {
 	Q_OBJECT
-  
 
 public:
 
 	static OTRPlugin  *plugin();
 
-	OTRPlugin( TQObject *parent, const char *name, const TQStringList &args );
+	OTRPlugin( TDEInstance *instance, TQObject *parent, const char *name, const TQStringList &args );
 	~OTRPlugin();
 
 	void emitGoneSecure( Kopete::ChatSession *session, int status );
@@ -113,7 +112,6 @@ private:
 signals:
 	void goneSecure( Kopete::ChatSession *session, int state );
 
-
 };
 
 #endif
